cmd

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 23, 2026 License: AGPL-3.0 Imports: 27 Imported by: 0

Documentation

Overview

Package cmd implements the do-manager CLI using Cobra.

Index

Constants

This section is empty.

Variables

var (
	Version   = "dev"
	Commit    = "none"
	BuildDate = "unknown"
)

These variables are overridden at build time via -ldflags.

Functions

func Execute

func Execute()

Execute is the main entry point called by main().

Types

This section is empty.

Jump to